import Vue from 'vue'
import App from './App.vue'
import TestVue from './TestVue.vue'
import GraphqlApp from './GraphqlApp.vue'
import AjaxApp from './AjaxApp.vue'
import apolloProvider from './apollo-provider'
import VueUIGrid from './vue-grid'
import axios from 'axios'

Vue.config.productionTip = false

axios.defaults.baseURL = 'http://localhost:3091/api/'

Vue.use(VueUIGrid, {
  graphql: true,
  ajax: true,
  fetchData: axios.get,
  extractData: (responseData: any) => {
    const data = responseData.data
    return {
      items: data.items,
      total: data.totalItems
    }
  },
  getPageIndex: (index: number) => (index + 1),

  graphqlFilter(column: any, value: string) {
    let result = ''

    if (column) {
      if (column.type === 'uuid') {
        result = `${column.field}: { _eq: "${value}" }`
      } else {
        result = `${column.field}: { _like: "%${value}%" }`
      }
    }

    return result
  },
  graphqlOrder(by: string, type: string) {
    return `order_by: { ${by}: ${type} }`
  },
  graphqlDataCounter: (data: any) => data.aggregate.count
})

new Vue({
  apolloProvider,
  render: h => h(GraphqlApp)
}).$mount('#app')
